@@ -38,7 +38,7 @@ class ConsoleWriter:
             try:
                 text = text.encode(self.dbEncoding)
             except UnicodeEncodeError:
-                text = repr(text)[1:-1]
+                text = repr(text)[2:-1]
         logfile.write(text + '\n')
 
 class LogWriter:
@@ -580,7 +580,10 @@ class DBAPI(DBConnection):
             data[soClass.sqlmeta.idName] = kw.pop('id')
         for key, col in soClass.sqlmeta.columns.items():
             if key in kw:
-                data[col.dbName] = kw.pop(key)
+                value = kw.pop(key)
+                if col.from_python:
+                    value = col.from_python(value, soClass)
+                data[col.dbName] = value
             elif col.foreignName in kw:
                 obj = kw.pop(col.foreignName)
                 if isinstance(obj, main.SQLObject):
@@ -956,3 +959,12 @@ registerConnection = TheURIOpener.registerConnection
 registerConnectionInstance = TheURIOpener.registerConnectionInstance
 connectionForURI = TheURIOpener.connectionForURI
 dbConnectionForScheme = TheURIOpener.dbConnectionForScheme
+
+# Register DB URI schemas
+import firebird
+import maxdb
+import mssql
+import mysql
+import postgres
+import sqlite
+import sybase
