@@ -1,6 +1,6 @@
 """
-SQLObject 0.11.6
---------------
+SQLObject 0.12.2
+----------------
 
 :author: Ian Bicking <ianb@colorstudy.com>
 
@@ -658,9 +658,9 @@ class _sqlmeta_attr(object):
 warnings_level = 1
 exception_level = None
 # Current levels:
-#  1) Actively deprecated in version after 0.9; removed after
-#  2) Deprecated after 1 (0.9?)
-#  3) Deprecated after 2 (0.10?)
+#  1) Actively deprecated
+#  2) Deprecated after 1
+#  3) Deprecated after 2
 
 def deprecated(message, level=1, stacklevel=2):
     if exception_level is not None and exception_level <= level:
@@ -814,8 +814,6 @@ class SQLObject(object):
 
         classregistry.registry(cls.sqlmeta.registry).addClass(cls)
 
-    _expired = _sqlmeta_attr('expired', 1)
-
     # @classmethod
     def _SO_setupSqlmeta(cls, new_attrs, is_base):
         """
@@ -866,7 +864,7 @@ class SQLObject(object):
         been deprecated; they are moved to the sqlmeta class, and
         a deprecation warning is given.
         """
-        for attr in ['_expired']:
+        for attr in ():
             if new_attrs.has_key(attr):
                 deprecated("%r is deprecated and read-only; please do "
                            "not use it in your classes until it is fully "
@@ -891,7 +889,7 @@ class SQLObject(object):
         if val is None:
             try:
                 val = cls(_SO_fetch_no_create=1)
-                val._SO_validatorState = SQLObjectState(val)
+                val._SO_validatorState = sqlbuilder.SQLObjectState(val)
                 val._init(id, connection, selectResults)
                 cache.put(id, cls, val)
             finally:
@@ -922,8 +920,7 @@ class SQLObject(object):
         # If no connection was given, we'll inherit the class
         # instance variable which should have a _connection
         # attribute.
-        if (connection is not None) and \
-                (getattr(self, '_connection', None) is not connection):
+        if (connection is not None) and (self._connection is not connection):
             self._connection = connection
             # Sometimes we need to know if this instance is
             # global or tied to a particular connection.
@@ -1210,7 +1207,7 @@ class SQLObject(object):
             # Pass the connection object along if we were given one.
             if kw.has_key('connection'):
                 connection = kw.pop('connection')
-                if getattr(self, '_connection', None) is not connection:
+                if self._connection is not connection:
                     self._connection = connection
                     self.sqlmeta._perConnection = True
 
@@ -1241,7 +1238,7 @@ class SQLObject(object):
 
         self.sqlmeta._creating = True
         self._SO_createValues = {}
-        self._SO_validatorState = SQLObjectState(self)
+        self._SO_validatorState = sqlbuilder.SQLObjectState(self)
 
         # First we do a little fix-up on the keywords we were
         # passed:
@@ -1310,16 +1307,18 @@ class SQLObject(object):
         return getID(obj)
 
     def _findAlternateID(cls, name, dbName, value, connection=None):
-        if isinstance(value, unicode):
-            column = cls.sqlmeta.columns[name]
-            if isinstance(column, col.SOUnicodeCol):
-                value = value.encode(column.dbEncoding)
         if isinstance(name, str):
             name = (name,)
             value = (value,)
         if len(name) != len(value):
             raise ValueError, "'column' and 'value' tuples must be of the same size"
-        condition = sqlbuilder.AND(*[getattr(cls.q, n)==v for n,v in zip(name, value)])
+        new_value = []
+        for n, v in zip(name, value):
+            from_python = getattr(cls, '_SO_from_python_' + n)
+            if from_python:
+                v = from_python(v, cls)
+            new_value.append(v)
+        condition = sqlbuilder.AND(*[getattr(cls.q, n)==v for n,v in zip(name, new_value)])
         return (connection or cls._connection)._SO_selectOneAlt(
             cls,
             [cls.sqlmeta.idName] +
@@ -1368,11 +1367,6 @@ class SQLObject(object):
     select = classmethod(select)
 
     def selectBy(cls, connection=None, **kw):
-        for key, column in cls.sqlmeta.columns.items():
-            if (key in kw) and isinstance(column, col.SOUnicodeCol):
-                value = kw[key]
-                if isinstance(value, unicode):
-                    kw[key] = value.encode(column.dbEncoding)
         conn = connection or cls._connection
         return cls.SelectResultsClass(cls,
                              conn._SO_columnClause(cls, kw),
@@ -1696,13 +1690,6 @@ def instanceName(name):
     return '_SO_val_%s' % name
 
 
-class SQLObjectState(object):
-
-    def __init__(self, soObject):
-        self.soObject = weakref.proxy(soObject)
-        self.protocol = 'sql'
-
-
 ########################################
 ## Utility functions (for external consumption)
 ########################################
