@@ -5,8 +5,6 @@ from sqlobject.dbconnection import DBAPI
 from sqlobject import col, sqlbuilder
 from sqlobject.dberrors import *
 
-sqlite = None
-using_sqlite2 = False
 sqlite2_Binary = None
 
 class ErrorMessage(str):
@@ -24,37 +22,42 @@ class SQLiteConnection(DBAPI):
     schemes = [dbName]
 
     def __init__(self, filename, autoCommit=1, **kw):
-        global sqlite
-        global using_sqlite2
-        if sqlite is None:
+        backends = kw.pop('backend', None) or 'pysqlite2,sqlite3,sqlite'
+        for backend in backends.split(','):
+            backend = backend.strip()
+            if not backend:
+                continue
             try:
-                from pysqlite2 import dbapi2 as sqlite
-                using_sqlite2 = True
+                if backend in ('sqlite2', 'pysqlite2'):
+                        from pysqlite2 import dbapi2 as sqlite
+                        self.using_sqlite2 = True
+                elif backend == 'sqlite3':
+                        import sqlite3 as sqlite
+                        self.using_sqlite2 = True
+                elif backend in ('sqlite', 'sqlite1'):
+                        import sqlite
+                        self.using_sqlite2 = False
+                else:
+                    raise ValueError('Unknown SQLite backend "%s", expected pysqlite2, sqlite3 or sqlite' % backend)
             except ImportError:
-                try:
-                    import sqlite3 as sqlite
-                    using_sqlite2 = True
-                except ImportError:
-                    import sqlite
-                    using_sqlite2 = False
-            if using_sqlite2:
-                sqlite.encode = base64.encodestring
-                sqlite.decode = base64.decodestring
+                pass
+            else:
+                break
+        else:
+            raise ImportError('Cannot find an SQLite backend, tried %s' % backends)
+        if self.using_sqlite2:
+            sqlite.encode = base64.encodestring
+            sqlite.decode = base64.decodestring
         self.module = sqlite
         self.filename = filename  # full path to sqlite-db-file
         self._memory = filename == ':memory:'
-        if self._memory:
-            if not using_sqlite2:
-                raise ValueError(
-                    "You must use sqlite2 to use in-memory databases")
+        if self._memory and not self.using_sqlite2:
+            raise ValueError("You must use sqlite2 to use in-memory databases")
         # connection options
         opts = {}
-        if using_sqlite2:
+        if self.using_sqlite2:
             if autoCommit:
                 opts["isolation_level"] = None
-            if 'encoding' in kw:
-                import warnings
-                warnings.warn(DeprecationWarning("pysqlite2 does not support the encoding option"))
             opts["detect_types"] = sqlite.PARSE_DECLTYPES
             for col_type in "text", "char", "varchar", "date", "time", "datetime", "timestamp":
                 sqlite.register_converter(col_type, stop_pysqlite2_converting_strings)
@@ -75,7 +78,7 @@ class SQLiteConnection(DBAPI):
             if 'mode' in kw:
                 opts['mode'] = int(kw.pop('mode'), 0)
         if 'timeout' in kw:
-            if using_sqlite2:
+            if self.using_sqlite2:
                 opts['timeout'] = float(kw.pop('timeout'))
             else:
                 opts['timeout'] = int(float(kw.pop('timeout')) * 1000)
@@ -156,7 +159,7 @@ class SQLiteConnection(DBAPI):
             conn.close()
 
     def _setAutoCommit(self, conn, auto):
-        if using_sqlite2:
+        if self.using_sqlite2:
             if auto:
                 conn.isolation_level = None
             else:
@@ -165,14 +168,14 @@ class SQLiteConnection(DBAPI):
             conn.autocommit = auto
 
     def _setIsolationLevel(self, conn, level):
-        if not using_sqlite2:
+        if not self.using_sqlite2:
             return
         conn.isolation_level = level
 
     def makeConnection(self):
         if self._memory:
             return self._memoryConn
-        return sqlite.connect(self.filename, **self._connOptions)
+        return self.module.connect(self.filename, **self._connOptions)
 
     def _executeRetry(self, conn, cursor, query):
         if self.debug:
@@ -362,7 +365,7 @@ class SQLiteConnection(DBAPI):
         elif t.find('REAL') >= 0 or t.find('FLOAT') >= 0:
             return col.FloatCol, {}
         elif t.find('DECIMAL') >= 0:
-            return col.DecimalCol, {'size': None, 'precision': None}
+            return col.DecimalCol, {}
         elif t.find('BOOL') >= 0:
             return col.BoolCol, {}
         else:
